@@ -12,7 +12,7 @@ from sbi.inference.potentials.posterior_based_potential import (
     posterior_estimator_based_potential,
 )
 from sbi.samplers.rejection.rejection import rejection_sample_posterior_within_prior
-from sbi.types import Shape
+from sbi.types import Shape, TorchTransform
 from sbi.utils import check_prior, match_theta_and_x_batch_shapes, within_support
 from sbi.utils.torchutils import ensure_theta_batched
 
@@ -35,6 +35,7 @@ class DirectPosterior(NeuralPosterior):
         self,
         posterior_estimator: flows.Flow,
         prior: Distribution,
+        theta_transform: Optional[TorchTransform] = None,
         max_sampling_batch_size: int = 10_000,
         device: Optional[str] = None,
         x_shape: Optional[torch.Size] = None,
@@ -43,6 +44,12 @@ class DirectPosterior(NeuralPosterior):
         Args:
             prior: Prior distribution with `.log_prob()` and `.sample()`.
             posterior_estimator: The trained neural posterior.
+            theta_transform: Custom transform to perform MAP optimization in
+                unconstrained space. If None (default), a suitable transform is
+                built from the prior support. In order to not use a transform at all,
+                pass an identity transform, e.g., `theta_transform=torch.distrbutions.
+                transforms`.
+                identity_transform()`.
             max_sampling_batch_size: Batchsize of samples being drawn from
                 the proposal at every iteration.
             device: Training device, e.g., "cpu", "cuda" or "cuda:0". If None,
@@ -55,7 +62,7 @@ class DirectPosterior(NeuralPosterior):
         # obtaining the MAP.
         check_prior(prior)
         potential_fn, theta_transform = posterior_estimator_based_potential(
-            posterior_estimator, prior, None
+            posterior_estimator, prior, x_o=None, theta_transform=theta_transform
         )
 
         super().__init__(
