@@ -1,19 +1,21 @@
 # This file is part of sbi, a toolkit for simulation-based inference. sbi is licensed
 # under the Affero General Public License v3, see <https://www.gnu.org/licenses/>.
 
+from typing import Optional
 
 from pyknos.mdn.mdn import MultivariateGaussianMDN
 from pyknos.nflows import flows, transforms
 from torch import Tensor, nn
 
 import sbi.utils as utils
+from sbi.utils.user_input_checks import check_data_device, check_embedding_net_device
 
 
 def build_mdn(
-    batch_x: Tensor = None,
-    batch_y: Tensor = None,
-    z_score_x: bool = True,
-    z_score_y: bool = True,
+    batch_x: Tensor,
+    batch_y: Tensor,
+    z_score_x: Optional[str] = "independent",
+    z_score_y: Optional[str] = "independent",
     hidden_features: int = 50,
     num_components: int = 10,
     embedding_net: nn.Module = nn.Identity(),
@@ -24,8 +26,14 @@ def build_mdn(
     Args:
         batch_x: Batch of xs, used to infer dimensionality and (optional) z-scoring.
         batch_y: Batch of ys, used to infer dimensionality and (optional) z-scoring.
-        z_score_x: Whether to z-score xs passing into the network.
-        z_score_y: Whether to z-score ys passing into the network.
+        z_score_x: Whether to z-score xs passing into the network, can be one of:
+            - `none`, or None: do not z-score.
+            - `independent`: z-score each dimension independently.
+            - `structured`: treat dimensions as related, therefore compute mean and std
+            over the entire batch, instead of per-dimension. Should be used when each
+            sample is, for example, a time series or an image.
+        z_score_y: Whether to z-score ys passing into the network, same options as
+            z_score_x.
         hidden_features: Number of hidden features.
         num_components: Number of components.
         embedding_net: Optional embedding network for y.
@@ -37,16 +45,22 @@ def build_mdn(
     """
     x_numel = batch_x[0].numel()
     # Infer the output dimensionality of the embedding_net by making a forward pass.
+    check_data_device(batch_x, batch_y)
+    check_embedding_net_device(embedding_net=embedding_net, datum=batch_y)
     y_numel = embedding_net(batch_y[:1]).numel()
 
     transform = transforms.IdentityTransform()
 
-    if z_score_x:
-        transform_zx = utils.standardizing_transform(batch_x)
+    z_score_x_bool, structured_x = utils.z_score_parser(z_score_x)
+    if z_score_x_bool:
+        transform_zx = utils.standardizing_transform(batch_x, structured_x)
         transform = transforms.CompositeTransform([transform_zx, transform])
 
-    if z_score_y:
-        embedding_net = nn.Sequential(utils.standardizing_net(batch_y), embedding_net)
+    z_score_y_bool, structured_y = utils.z_score_parser(z_score_y)
+    if z_score_y_bool:
+        embedding_net = nn.Sequential(
+            utils.standardizing_net(batch_y, structured_y), embedding_net
+        )
 
     distribution = MultivariateGaussianMDN(
         features=x_numel,
