@@ -6,8 +6,12 @@ from typing import NewType, Optional, Sequence, Tuple, TypeVar, Union
 
 import numpy as np
 import torch
+from pyro.distributions import TransformedDistribution
+from torch import Tensor
+from torch.distributions import Distribution
+from torch.distributions.transforms import Transform
 from torch.nn import Module
-from torch.utils.tensorboard import SummaryWriter
+from torch.utils.tensorboard.writer import SummaryWriter
 
 Array = Union[np.ndarray, torch.Tensor]
 Shape = Union[torch.Size, Tuple[int, ...]]
@@ -27,7 +31,13 @@ transform_types = Optional[
 # Define alias types because otherwise, the documentation by mkdocs became very long and
 # made the website look ugly.
 TensorboardSummaryWriter = NewType("Writer", SummaryWriter)
+TorchTransform = NewType("torch Transform", Transform)
 TorchModule = NewType("Module", Module)
+TorchDistribution = NewType("torch Distribution", Distribution)
+PyroTransformedDistribution = NewType(
+    "pyro TransformedDistribution", TransformedDistribution
+)
+TorchTensor = NewType("Tensor", Tensor)
 
 __all__ = [
     "Array",
@@ -37,4 +47,7 @@ __all__ = [
     "TensorboardSummaryWriter",
     "TorchModule",
     "transform_types",
+    "TorchDistribution",
+    "PyroTransformedDistribution",
+    "TorchTensor",
 ]
