@@ -627,3 +627,25 @@ def test_example_posterior(snpe_method: type):
         prior=prior, posterior_estimator=posterior_estimator
     ).set_default_x(x_o)
     assert posterior is not None
+
+
+@pytest.mark.slow
+def test_multiround_mog_training():
+    "Test whether multi-round training with MDNs is stable. See #669."
+
+    def simulator(theta):
+        return theta + torch.randn(theta.shape)
+
+    dim = 15
+    x_o = torch.zeros((1, dim))
+
+    prior = utils.BoxUniform(-3 * torch.ones(dim), 3 * torch.ones(dim))
+
+    proposal = prior
+    inference = SNPE_C(prior, density_estimator="mdn")
+
+    for _ in range(3):
+        theta, x = simulate_for_sbi(simulator, proposal, 200)
+        _ = inference.append_simulations(theta, x, proposal=proposal).train()
+        posterior = inference.build_posterior().set_default_x(x_o)
+        proposal = posterior
